==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_YOURNAME","O seu nome");
define("_SORTASC","Ordem crescente");
define("_SORTDESC","Ordem decrescente");
define("_CANCEL","Cancela");
define("_YES","Sim");
define("_NO","No");
define("_SCORE","Pontos:");
define("_REPLYMAIN","Enviar comentrio");
define("_ALLOWEDHTML","Cdigo HTML que pode inserir:");
define("_POSTANON","Enviar como annimo");
define("_WRITEREVIEW","Escreva uma reviso");
define("_WRITEREVIEWFOR","Escreva uma reviso para");
define("_ENTERINFO","Por favor insira as informaes de acordo com as especificaes");
define("_PRODUCTTITLE","Ttulo da reviso");
define("_NAMEPRODUCT","Nome do que vai ser revisto.");
define("_REVIEW","Reviso");
define("_CHECKREVIEW","A sua reviso actual. Por favor observe a gramtica! Faa isto com pelo menos 100 palavras, OK? Voc pode usar cdigo HTML e as suas codificaes se souber usar.");
define("_FULLNAMEREQ","O seu nome completo. Necessrio.");
define("_REMAIL","O seu email");
define("_REMAILREQ","O seu endereo de email. Necessrio.");
define("_SELECTSCORE","Pontuao do que est a rever (de 1 a 10)");
define("_RELATEDLINK","Link relacionado");
define("_PRODUCTSITE","Website oficial. Confira se o endereo comea mesmo com \"http://\"");
define("_LINKTITLE","Ttulo do Link ");
define("_LINKTITLEREQ","Necessrio se tiver um web site relacionado, caso contrrio  opcional.");
define("_RIMAGEFILE","Nome da Figura");
define("_RIMAGEFILEREQ","Nome da imagem correspondente, localizada em images/reviews. Facultativo.");
define("_CHECKINFO","Por favor verifique se a informao que voc colocou  100% correcta e est com a gramtica correcta.");
define("_INVALIDTITLE","Por favor fornea um ttulo...");
define("_INVALIDSCORE","Atribua a pontuao com um valor entre 1 e 10...");
define("_INVALIDTEXT","Texto de reviso invlido... No pode estar em branco...");
define("_INVALIDHITS","Nmeros devem ser um inteiro positivo");
define("_CHECKNAME","Por favor diga-nos qual  o seu nome e email");
define("_INVALIDEMAIL","Email invlido (ex: voce@hotmail.com)");
define("_INVALIDLINK","Deve informar o ttulo do link e um link relacionado ou deixar ambos os espaos em branco");
define("_ADDED","Adicionar:");
define("_REVIEWER","Revisor:");
define("_REVIEWID","ID da Reviso");
define("_HITS","Hits");
define("_LOOKSRIGHT","Parece correcto?");
define("_RMODIFIED","modificado");
define("_RADDED","Adicionado");
define("_ADMINLOGGED","Actualmente a administrao est ligada... esta reviso ser imediata");
define("_RTHANKS","Obrigado por enviar esta reviso");
define("_MODIFICATION","modificao");
define("_ISAVAILABLE","Est agora disponvel para modificao.");
define("_EDITORWILLLOOK","O web site vai analisar a sua emisso. Ficar disponvel em breve!");
define("_RBACK","Voltar ao ndice de revises");
define("_RWELCOME","Bem vindo  seco de Reviso");
define("_10MOSTPOP","As 10 primeiras revises");
define("_10MOSTREC","As 10 mais recentes revises");
define("_THEREARE","H");
define("_REVIEWSINDB","Revises disponveis");
define("_REVIEWS","Reviso");
define("_REVIEWSLETTER","Revises para carta");
define("_NOREVIEWS","Nem todas as revises so para carta");
define("_TOTALREVIEWS","Total de revises encontradas.");
define("_RETURN2MAIN","Voltar ao menu principal");
define("_REVIEWCOMMENT","Faa um comentrio sobre a reviso:");
define("_YOURNICK","O seu nome:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Crie</a> uma conta");
define("_YOURCOMMENT","O seu comentrio:");
define("_MYSCORE","A minha pontuao (1 a 10):");
define("_REVIEWMOD","Reviso modificada");
define("_RDATE","Data:");
define("_RTITLE","Ttulo:");
define("_RTEXT","Texto:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Ttulo do link:");
define("_COVERIMAGE","Imagem correspondente:");
define("_PREMODS","Visualizar modificaes");
define("_PAGE","Pginas");
define("_PAGEBREAK","Se voc quer escrever muito textos voc pode <b>&lt;!--pagebreak--&gt;</b> escrever um texto em partes.");
define("_PREVIEW","Pr-Visualizao");
define("_LANGUAGE","Lngua");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_YOURNAME","O seu nome");
define("_SORTASC","Ordem crescente");
define("_SORTDESC","Ordem decrescente");
define("_CANCEL","Cancela");
define("_YES","Sim");
define("_NO","No");
define("_SCORE","Pontos:");
define("_REPLYMAIN","Enviar comentrio");
define("_ALLOWEDHTML","Cdigo HTML que pode inserir:");
define("_POSTANON","Enviar como annimo");
define("_WRITEREVIEW","Escreva uma reviso");
define("_WRITEREVIEWFOR","Escreva uma reviso para");
define("_ENTERINFO","Por favor insira as informaes de acordo com as especificaes");
define("_PRODUCTTITLE","Ttulo da reviso");
define("_NAMEPRODUCT","Nome do que vai ser revisto.");
define("_REVIEW","Reviso");
define("_CHECKREVIEW","A sua reviso actual. Por favor observe a gramtica! Faa isto com pelo menos 100 palavras, OK? Voc pode usar cdigo HTML e as suas codificaes se souber usar.");
define("_FULLNAMEREQ","O seu nome completo. Necessrio.");
define("_REMAIL","O seu email");
define("_REMAILREQ","O seu endereo de email. Necessrio.");
define("_SELECTSCORE","Pontuao do que est a rever (de 1 a 10)");
define("_RELATEDLINK","Link relacionado");
define("_PRODUCTSITE","Website oficial. Confira se o endereo comea mesmo com \"http://\"");
define("_LINKTITLE","Ttulo do Link ");
define("_LINKTITLEREQ","Necessrio se tiver um web site relacionado, caso contrrio  opcional.");
define("_RIMAGEFILE","Nome da Figura");
define("_RIMAGEFILEREQ","Nome da imagem correspondente, localizada em images/reviews. Facultativo.");
define("_CHECKINFO","Por favor verifique se a informao que voc colocou  100% correcta e est com a gramtica correcta.");
define("_INVALIDTITLE","Por favor fornea um ttulo...");
define("_INVALIDSCORE","Atribua a pontuao com um valor entre 1 e 10...");
define("_INVALIDTEXT","Texto de reviso invlido... No pode estar em branco...");
define("_INVALIDHITS","Nmeros devem ser um inteiro positivo");
define("_CHECKNAME","Por favor diga-nos qual  o seu nome e email");
define("_INVALIDEMAIL","Email invlido (ex: voce@hotmail.com)");
define("_INVALIDLINK","Deve informar o ttulo do link e um link relacionado ou deixar ambos os espaos em branco");
define("_ADDED","Adicionar:");
define("_REVIEWER","Revisor:");
define("_REVIEWID","ID da Reviso");
define("_HITS","Hits");
define("_LOOKSRIGHT","Parece correcto?");
define("_RMODIFIED","modificado");
define("_RADDED","Adicionado");
define("_ADMINLOGGED","Actualmente a administrao est ligada... esta reviso ser imediata");
define("_RTHANKS","Obrigado por enviar esta reviso");
define("_MODIFICATION","modificao");
define("_ISAVAILABLE","Est agora disponvel para modificao.");
define("_EDITORWILLLOOK","O web site vai analisar a sua emisso. Ficar disponvel em breve!");
define("_RBACK","Voltar ao ndice de revises");
define("_RWELCOME","Bem vindo  seco de Reviso");
define("_10MOSTPOP","As 10 primeiras revises");
define("_10MOSTREC","As 10 mais recentes revises");
define("_THEREARE","H");
define("_REVIEWSINDB","Revises disponveis");
define("_REVIEWS","Reviso");
define("_REVIEWSLETTER","Revises para carta");
define("_NOREVIEWS","Nem todas as revises so para carta");
define("_TOTALREVIEWS","Total de revises encontradas.");
define("_RETURN2MAIN","Voltar ao menu principal");
define("_REVIEWCOMMENT","Faa um comentrio sobre a reviso:");
define("_YOURNICK","O seu nome:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Crie</a> uma conta");
define("_YOURCOMMENT","O seu comentrio:");
define("_MYSCORE","A minha pontuao (1 a 10):");
define("_REVIEWMOD","Reviso modificada");
define("_RDATE","Data:");
define("_RTITLE","Ttulo:");
define("_RTEXT","Texto:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Ttulo do link:");
define("_COVERIMAGE","Imagem correspondente:");
define("_PREMODS","Visualizar modificaes");
define("_PAGE","Pginas");
define("_PAGEBREAK","Se voc quer escrever muito textos voc pode <b>&lt;!--pagebreak--&gt;</b> escrever um texto em partes.");
define("_PREVIEW","Pr-Visualizao");
define("_LANGUAGE","Lngua");

?>
